let scrollInterval;
function scrollToH6Elements() {
    const h6Elements = document.querySelectorAll('h6');
    let currentElementIndex = 0;

    function scrollToElement() {
        if (currentElementIndex >= h6Elements.length) {
            currentElementIndex = 0; // Reset to the first element when reaching the end
        }

        const element = h6Elements[currentElementIndex];

        if (!element) { // Check if the element exists
            console.log("FAIL");
            return; // Exit the function if the element does not exist
        }

        const offsetTop = element.offsetTop;

        // Manually adjust the scroll position if needed, for example, to account for a fixed header
        const adjustedTop = offsetTop - 60; // Adjust the offset as needed

        window.scrollTo({ top: adjustedTop, behavior: 'smooth' });

        currentElementIndex++; // Move to the next element
    }

    scrollInterval = setInterval(scrollToElement, 30000); // 30000 ms = 30 seconds
}

function cancelScrolling() {
    if (scrollInterval) {
        clearInterval(scrollInterval);
        scrollInterval = null;
    }
}

function triggerFileInput() {
    document.getElementById('fileInput').click();
}

function downloadJson(jsonData, filename) {
    // Create a Blob from the JSON data
    const blob = new Blob([jsonData], { type: 'application/json' });
    const url = URL.createObjectURL(blob);

    // Create an anchor (<a>) element and trigger download
    const a = document.createElement('a');
    a.href = url;
    a.download = filename || 'backup.json'; // Default filename if none provided
    document.body.appendChild(a);
    a.click();
    document.body.removeChild(a);

    // Clean up by revoking the object URL
    URL.revokeObjectURL(url);
}

function generatePDF(htmlId) {
    const element = document.getElementById(htmlId);

    // Set options for html2canvas
    const canvasOptions = {
        scale: 2, // Increase scale to enhance quality
        logging: true,
        useCORS: true // To handle cross-origin images if any
    };

    html2canvas(element, canvasOptions).then(canvas => {
        const imgData = canvas.toDataURL('image/png');

        // Determine the PDF page width and height based on the canvas size
        const pdfWidth = canvas.width * 0.75;  // scale down the canvas width for PDF
        const pdfHeight = canvas.height * 0.75;

        // Create PDF and add image
        const pdf = new jspdf.jsPDF({
            orientation: 'landscape', // or 'portrait' based on your content orientation
            unit: 'pt',
            format: [pdfWidth, pdfHeight]
        });

        pdf.addImage(imgData, 'PNG', 0, 0, pdfWidth, pdfHeight);
        pdf.save("download.pdf");
    });
}

